==> ZenTaoPMS.max2.2.php7.1.zip: zentaopms/module/workflowfield/lang/en.php <==
<?php
$lang->workflowfield->common         = 'Workflow Field';
$lang->workflowfield->browse         = 'Fields';
$lang->workflowfield->create         = 'Create Field';
$lang->workflowfield->edit           = 'Edit Field';
$lang->workflowfield->delete         = 'Delete Field';
$lang->workflowfield->import         = 'Import Field';
$lang->workflowfield->showImport     = 'Show Import';
$lang->workflowfield->exportTemplate = 'Download Template';
$lang->workflowfield->sort           = 'Sort Field';
$lang->workflowfield->setValue       = 'Display Values';
$lang->workflowfield->setExport      = 'Export Settings';
$lang->workflowfield->setSearch      = 'Search Settings';
$lang->workflowfield->settings       = 'Field and attribute settings';

$lang->workflowfield->id           = 'ID';
$lang->workflowfield->module       = 'Module';
$lang->workflowfield->field        = 'Field';
$lang->workflowfield->type         = 'Data Type';
$lang->workflowfield->length       = 'Length';
$lang->workflowfield->name         = 'Name';
$lang->workflowfield->control      = 'Control';
$lang->workflowfield->expression   = 'Expression';
$lang->workflowfield->options      = 'Option';
$lang->workflowfield->defaultValue = 'Default';
$lang->workflowfield->rules        = 'Rule';
$lang->workflowfield->placeholder  = 'Placeholder';
$lang->workflowfield->canSetValue  = 'Enable Display Values';
$lang->workflowfield->canExport    = 'Enable Export';
$lang->workflowfield->canSearch    = 'Enable Search';
$lang->workflowfield->isKeyValue   = 'Key-Value';
$lang->workflowfield->order        = 'Order';
$lang->workflowfield->buildin      = 'Build-in';
$lang->workflowfield->desc         = 'Description';
$lang->workflowfield->createdBy    = 'Created By';
$lang->workflowfield->createdDate  = 'Created';
$lang->workflowfield->editedBy     = 'Edited By';
$lang->workflowfield->editedDate   = 'Edited';

$lang->workflowfield->position         = 'Position';
$lang->workflowfield->datasource       = 'DataSource';
$lang->workflowfield->sql              = 'SQL';
$lang->workflowfield->vars             = 'Vars';
$lang->workflowfield->addVar           = 'Add Var';
$lang->workflowfield->varName          = 'Var Name';
$lang->workflowfield->showName         = 'Show Name';
$lang->workflowfield->requestType      = 'Control';
$lang->workflowfield->status           = 'Status';
$lang->workflowfield->subStatus        = 'Sub Status';
$lang->workflowfield->key              = 'Key';
$lang->workflowfield->value            = 'Value';
$lang->workflowfield->defaultSubStatus = 'Default';
$lang->workflowfield->fieldName        = 'Field Name';
$lang->workflowfield->tableParent      = 'Parent ID';
$lang->workflowfield->template         = 'Fields Template';

$lang->workflowfield->integerDigits = 'Integer Digits';
$lang->workflowfield->decimalDigits = 'Decimal Digits';

$lang->workflowfield->typeGroup['integer']  = 'Integer';
$lang->workflowfield->typeGroup['decimal']  = 'Decimal';
$lang->workflowfield->typeGroup['date']     = 'Date';
$lang->workflowfield->typeGroup['time']     = 'Time';
$lang->workflowfield->typeGroup['varchar']  = 'Text';
$lang->workflowfield->typeGroup['text']     = 'Multiline Text';

$lang->workflowfield->controlTypeList['label']        = 'Label';
$lang->workflowfield->controlTypeList['input']        = 'Text';
$lang->workflowfield->controlTypeList['textarea']     = 'Multiline Text';
$lang->workflowfield->controlTypeList['select']       = 'Dropdown';
$lang->workflowfield->controlTypeList['multi-select'] = 'Multi-Dropdown';
$lang->workflowfield->controlTypeList['radio']        = 'Radio';
$lang->workflowfield->controlTypeList['checkbox']     = 'Checkbox';
$lang->workflowfield->controlTypeList['richtext']     = 'Richtext';
$lang->workflowfield->controlTypeList['date']         = 'Date';
$lang->workflowfield->controlTypeList['datetime']     = 'Time';
$lang->workflowfield->controlTypeList['decimal']      = 'Decimal';
$lang->workflowfield->controlTypeList['integer']      = 'Integer';
$lang->workflowfield->controlTypeList['formula']      = 'Expression';
$lang->workflowfield->controlTypeList['file']         = 'File';

$lang->workflowfield->optionTypeList['sql']        = 'SQL';
$lang->workflowfield->optionTypeList['category']   = 'Category';
$lang->workflowfield->optionTypeList['prevModule'] = 'Prev Flow';

$lang->workflowfield->positionList['before'] = 'Before';
$lang->workflowfield->positionList['after']  = 'After';

$lang->workflowfield->exportList[1] = 'Yes';
$lang->workflowfield->exportList[0] = 'No';

$lang->workflowfield->searchList[1] = 'Yes';
$lang->workflowfield->searchList[0] = 'No';

$lang->workflowfield->keyValueList['key']   = 'Key';
$lang->workflowfield->keyValueList['value'] = 'Value';

$lang->workflowfield->buildinList['0'] = 'No';
$lang->workflowfield->buildinList['1'] = 'Yes';

$lang->workflowfield->default = new stdclass();
$lang->workflowfield->default->fields['id']           = 'ID';
$lang->workflowfield->default->fields['parent']       = 'Parent';
$lang->workflowfield->default->fields['assignedTo']   = 'Assigned To';
$lang->workflowfield->default->fields['status']       = 'Status';
$lang->workflowfield->default->fields['createdBy']    = 'Created By';
$lang->workflowfield->default->fields['createdDate']  = 'Created';
$lang->workflowfield->default->fields['editedBy']     = 'Edited By';
$lang->workflowfield->default->fields['editedDate']   = 'Edited';
$lang->workflowfield->default->fields['assignedBy']   = 'Assigned By';
$lang->workflowfield->default->fields['assignedDate'] = 'Assigned';
$lang->workflowfield->default->fields['mailto']       = 'Mailto';
$lang->workflowfield->default->fields['deleted']      = 'Deleted';

$lang->workflowfield->default->options = new stdclass();
$lang->workflowfield->default->options->deleted = array();
$lang->workflowfield->default->options->deleted['0'] = 'Undeleted';
$lang->workflowfield->default->options->deleted['1'] = 'Deleted';

/* Tips */
$lang->workflowfield->tips = new stdclass();
$lang->workflowfield->tips->keyValue     = "<strong>Display Values</strong> are used to display the flow data when they are called by other flows.<br /><strong>Display Values</strong> can be several ones, and multiple values will be connected by space when display.<br />If there isn't display value, the flow data will display as the format <strong>the flow name + ID</strong>.";
$lang->workflowfield->tips->lengthNotice = 'Attention! It will cause data lose.';
$lang->workflowfield->tips->emptyStatus  = 'Set options of the status field first.';
$lang->workflowfield->tips->emptyValue   = 'No fields selected and can not enable the display value function. Sure to save?';
$lang->workflowfield->tips->emptyExport  = 'No fields selected for the table <strong>TABLE</strong> and can not enable the search function. Sure to save?';
$lang->workflowfield->tips->emptySearch  = 'No fields selected and can not enable the search function. Sure to save?';
$lang->workflowfield->tips->number       = 'The max is MAX, the min is MIN.';
$lang->workflowfield->tips->string       = 'Up to LENGTH characters and punctuation marks.';

/* Placeholder */
$lang->workflowfield->placeholder = new stdclass();
$lang->workflowfield->placeholder->code          = 'Should be letters';
$lang->workflowfield->placeholder->sql           = 'Use a SQL query. Only the query is allowed. Other SQL operations are prohibited. The query result is key-value pairs. The 1st field of query will be the key of result and the 2nd one be the value. Other fields will be ignored. If there is only one field, it will be the key and the value';
$lang->workflowfield->placeholder->defaultValue  = 'Seperated by space or comma.';
$lang->workflowfield->placeholder->optionCode    = 'It should be letters or numbers.';
$lang->workflowfield->placeholder->auto          = 'Automatically generated by the system';
$lang->workflowfield->placeholder->varcharLength = 'Default 255, max 1000, min 1';
$lang->workflowfield->placeholder->charLength    = 'Default 50, max 255, min 1';
$lang->workflowfield->placeholder->integerDigits = 'Default 10, max 12, min 1';
$lang->workflowfield->placeholder->decimalDigits = 'Default 2, max 5, min 1';

/* Alert */
$lang->workflowfield->alert = new stdclass();
$lang->workflowfield->alert->common                       = 'Alert';
$lang->workflowfield->alert->update                       = 'The field may be used in below functions, please check and update manually.';
$lang->workflowfield->alert->delete                       = 'The field may be used in below functions, please check and delete manually.';
$lang->workflowfield->alert->separater                    = ', ';
$lang->workflowfield->alert->types['fieldExpression']     = "The expression of the <strong>%s</strong> fields of the <strong>%s</strong> flow.";
$lang->workflowfield->alert->types['conditionSql']        = "The <strong>SQL of conditions</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['verificationSql']     = "The <strong>SQL of verifications</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['verificationSqlVar']  = "The SQL variables <strong>%s</strong> of the verifications of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionSql']    = "The <strong>SQL of hook's conditions</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionSqlVar'] = "The SQL variables <strong>%s</strong> of the hooks' conditions of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionField']  = "The <strong>%s</strong> fields of the hooks' conditions of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookField']           = "The <strong>%s</strong> fields of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookFieldFormula']    = "The expression of the <strong>%s</strong> fields of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookWhere']           = "The <strong>%s</strong> conditions of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";

/* Error */
$lang->workflowfield->error = new stdclass();
$lang->workflowfield->error->remainFields     = '<strong> %s </strong> is a reserved keyword in the system, please change the field code.';
$lang->workflowfield->error->emptyOptions     = 'Empty <strong>key</strong> and <strong>value</strong>.';
$lang->workflowfield->error->wrongCode        = 'The <strong> %s </strong> should be letters.';
$lang->workflowfield->error->longCode         = 'The length of the <strong> %s </strong> should not exceed 30.';
$lang->workflowfield->error->wrongSQL         = 'The SQL is wrong! Error: ';
$lang->workflowfield->error->notunique        = 'unique check';
$lang->workflowfield->error->defaultValue     = 'The length of the <strong> default value </strong> should not exceed %s.';
$lang->workflowfield->error->textDefaultValue = 'The text-field has no default value.';
$lang->workflowfield->error->duplicatedCode   = 'Please reset the duplicated <strong>Keys</strong> %s .';
$lang->workflowfield->error->emptyDefault     = 'Select a item as <strong>default</strong>.';
$lang->workflowfield->error->emptyCustomField = 'You have not added a field. Add one first.';
$lang->workflowfield->error->length           = '<strong>%s</strong> should be greater than or equal to <strong>%s</strong>, and less than or equal to <strong>%s</strong>.';
$lang->workflowfield->error->digits           = '<strong>%s</strong> should be greater than or equal to <strong>%s</strong>.';
$lang->workflowfield->error->dateFormat       = '<strong> Date </strong> format is wrong, must be Y-m-d.';
$lang->workflowfield->error->timeFormat       = '<strong> Datetime </strong> format is wrong, must be Y-m-d H:i:s.';
$lang->workflowfield->error->intSize          = 'The length of the <strong> default value </strong> should be greater than or equal to %s,and less than or equal to %s .';

/* Formula */
$lang->workflowfield->formula = new stdclass();
$lang->workflowfield->formula->common    = 'Expression';
$lang->workflowfield->formula->target    = 'Target';
$lang->workflowfield->formula->operator  = 'Operator';
$lang->workflowfield->formula->numbers   = 'Number';
$lang->workflowfield->formula->clearLast = 'Delete';
$lang->workflowfield->formula->clearAll  = 'Delete All';
$lang->workflowfield->formula->set       = 'Setting';

$lang->workflowfield->formula->functions['sum']     = 'Total_%s_%s';
$lang->workflowfield->formula->functions['average'] = 'Average_%s_%s';
$lang->workflowfield->formula->functions['max']     = 'Max_%s_%s';
$lang->workflowfield->formula->functions['min']     = 'Min_%s_%s';
$lang->workflowfield->formula->functions['count']   = 'Quantity_%s_%s';

$lang->workflowfield->formula->error = new stdclass();
$lang->workflowfield->formula->error->empty = 'Expression can not be empty.';
$lang->workflowfield->formula->error->error = 'Expression is not correct.';

$lang->workflowfield->excel = new stdclass();
$lang->workflowfield->excel->tips = "1. Name and Field is required. 2. The Options should be in 'key,value' format, separated by comma, multiple groups separated by a newline.";

==> ZenTaoPMS.max2.4.php5.3_5.6.zip: zentaopms/module/workflowfield/lang/en.php <==
<?php
$lang->workflowfield->common         = 'Workflow Field';
$lang->workflowfield->browse         = 'Fields';
$lang->workflowfield->create         = 'Create Field';
$lang->workflowfield->edit           = 'Edit Field';
$lang->workflowfield->delete         = 'Delete Field';
$lang->workflowfield->import         = 'Import Field';
$lang->workflowfield->showImport     = 'Show Import';
$lang->workflowfield->exportTemplate = 'Download Template';
$lang->workflowfield->sort           = 'Sort Field';
$lang->workflowfield->setValue       = 'Display Values';
$lang->workflowfield->setExport      = 'Export Settings';
$lang->workflowfield->setSearch      = 'Search Settings';
$lang->workflowfield->settings       = 'Field and attribute settings';

$lang->workflowfield->id           = 'ID';
$lang->workflowfield->module       = 'Module';
$lang->workflowfield->field        = 'Field';
$lang->workflowfield->type         = 'Data Type';
$lang->workflowfield->length       = 'Length';
$lang->workflowfield->name         = 'Name';
$lang->workflowfield->control      = 'Control';
$lang->workflowfield->expression   = 'Expression';
$lang->workflowfield->options      = 'Option';
$lang->workflowfield->defaultValue = 'Default';
$lang->workflowfield->rules        = 'Rule';
$lang->workflowfield->placeholder  = 'Placeholder';
$lang->workflowfield->canSetValue  = 'Enable Display Values';
$lang->workflowfield->canExport    = 'Enable Export';
$lang->workflowfield->extendExport = 'Extend Export';
$lang->workflowfield->canSearch    = 'Enable Search';
$lang->workflowfield->extendSearch = 'Extend Search';
$lang->workflowfield->isKeyValue   = 'Key-Value';
$lang->workflowfield->order        = 'Order';
$lang->workflowfield->buildin      = 'Build-in';
$lang->workflowfield->desc         = 'Description';
$lang->workflowfield->createdBy    = 'Created By';
$lang->workflowfield->createdDate  = 'Created';
$lang->workflowfield->editedBy     = 'Edited By';
$lang->workflowfield->editedDate   = 'Edited';

$lang->workflowfield->position         = 'Position';
$lang->workflowfield->datasource       = 'DataSource';
$lang->workflowfield->sql              = 'SQL';
$lang->workflowfield->vars             = 'Vars';
$lang->workflowfield->addVar           = 'Add Var';
$lang->workflowfield->varName          = 'Var Name';
$lang->workflowfield->showName         = 'Show Name';
$lang->workflowfield->requestType      = 'Control';
$lang->workflowfield->status           = 'Status';
$lang->workflowfield->subStatus        = 'Sub Status';
$lang->workflowfield->key              = 'Key';
$lang->workflowfield->value            = 'Value';
$lang->workflowfield->defaultSubStatus = 'Default';
$lang->workflowfield->fieldName        = 'Field Name';
$lang->workflowfield->tableParent      = 'Parent ID';
$lang->workflowfield->template         = 'Fields Template';

$lang->workflowfield->integerDigits = 'Integer Digits';
$lang->workflowfield->decimalDigits = 'Decimal Digits';

$lang->workflowfield->typeGroup['integer']  = 'Integer';
$lang->workflowfield->typeGroup['decimal']  = 'Decimal';
$lang->workflowfield->typeGroup['date']     = 'Date';
$lang->workflowfield->typeGroup['time']     = 'Time';
$lang->workflowfield->typeGroup['varchar']  = 'Text';
$lang->workflowfield->typeGroup['text']     = 'Multiline Text';

$lang->workflowfield->controlTypeList['label']        = 'Label';
$lang->workflowfield->controlTypeList['input']        = 'Text';
$lang->workflowfield->controlTypeList['textarea']     = 'Multiline Text';
$lang->workflowfield->controlTypeList['select']       = 'Dropdown';
$lang->workflowfield->controlTypeList['multi-select'] = 'Multi-Dropdown';
$lang->workflowfield->controlTypeList['radio']        = 'Radio';
$lang->workflowfield->controlTypeList['checkbox']     = 'Checkbox';
$lang->workflowfield->controlTypeList['richtext']     = 'Richtext';
$lang->workflowfield->controlTypeList['date']         = 'Date';
$lang->workflowfield->controlTypeList['datetime']     = 'Time';
$lang->workflowfield->controlTypeList['decimal']      = 'Decimal';
$lang->workflowfield->controlTypeList['integer']      = 'Integer';
$lang->workflowfield->controlTypeList['formula']      = 'Expression';
$lang->workflowfield->controlTypeList['file']         = 'File';

$lang->workflowfield->optionTypeList['sql']        = 'SQL';
$lang->workflowfield->optionTypeList['category']   = 'Category';
$lang->workflowfield->optionTypeList['prevModule'] = 'Prev Flow';

$lang->workflowfield->positionList['before'] = 'Before';
$lang->workflowfield->positionList['after']  = 'After';

$lang->workflowfield->exportList[1] = 'Yes';
$lang->workflowfield->exportList[0] = 'No';

$lang->workflowfield->searchList[1] = 'Yes';
$lang->workflowfield->searchList[0] = 'No';

$lang->workflowfield->keyValueList['key']   = 'Key';
$lang->workflowfield->keyValueList['value'] = 'Value';

$lang->workflowfield->buildinList['0'] = 'No';
$lang->workflowfield->buildinList['1'] = 'Yes';

$lang->workflowfield->default = new stdclass();
$lang->workflowfield->default->fields['id']           = 'ID';
$lang->workflowfield->default->fields['parent']       = 'Parent';
$lang->workflowfield->default->fields['assignedTo']   = 'Assigned To';
$lang->workflowfield->default->fields['status']       = 'Status';
$lang->workflowfield->default->fields['createdBy']    = 'Created By';
$lang->workflowfield->default->fields['createdDate']  = 'Created';
$lang->workflowfield->default->fields['editedBy']     = 'Edited By';
$lang->workflowfield->default->fields['editedDate']   = 'Edited';
$lang->workflowfield->default->fields['assignedBy']   = 'Assigned By';
$lang->workflowfield->default->fields['assignedDate'] = 'Assigned';
$lang->workflowfield->default->fields['mailto']       = 'Mailto';
$lang->workflowfield->default->fields['deleted']      = 'Deleted';

$lang->workflowfield->default->options = new stdclass();
$lang->workflowfield->default->options->deleted = array();
$lang->workflowfield->default->options->deleted['0'] = 'Undeleted';
$lang->workflowfield->default->options->deleted['1'] = 'Deleted';

/* Tips */
$lang->workflowfield->tips = new stdclass();
$lang->workflowfield->tips->keyValue     = "<strong>Display Values</strong> are used to display the flow data when they are called by other flows.<br /><strong>Display Values</strong> can be several ones, and multiple values will be connected by space when display.<br />If there isn't display value, the flow data will display as the format <strong>the flow name + ID</strong>.";
$lang->workflowfield->tips->lengthNotice = 'Attention! It will cause data lose.';
$lang->workflowfield->tips->emptyStatus  = 'Set options of the status field first.';
$lang->workflowfield->tips->emptyValue   = 'No fields selected and can not enable the display value function. Sure to save?';
$lang->workflowfield->tips->emptyExport  = 'No fields selected for the table <strong>TABLE</strong> and can not enable the search function. Sure to save?';
$lang->workflowfield->tips->emptySearch  = 'No fields selected and can not enable the search function. Sure to save?';
$lang->workflowfield->tips->number       = 'The max is MAX, the min is MIN.';
$lang->workflowfield->tips->string       = 'Up to LENGTH characters and punctuation marks.';

/* Placeholder */
$lang->workflowfield->placeholder = new stdclass();
$lang->workflowfield->placeholder->code          = 'Should be letters';
$lang->workflowfield->placeholder->sql           = 'Use a SQL query. Only the query is allowed. Other SQL operations are prohibited. The query result is key-value pairs. The 1st field of query will be the key of result and the 2nd one be the value. Other fields will be ignored. If there is only one field, it will be the key and the value';
$lang->workflowfield->placeholder->defaultValue  = 'Seperated by space or comma.';
$lang->workflowfield->placeholder->optionCode    = 'It should be letters or numbers.';
$lang->workflowfield->placeholder->auto          = 'Automatically generated by the system';
$lang->workflowfield->placeholder->varcharLength = 'Default 255, max 1000, min 1';
$lang->workflowfield->placeholder->charLength    = 'Default 50, max 255, min 1';
$lang->workflowfield->placeholder->integerDigits = 'Default 10, max 12, min 1';
$lang->workflowfield->placeholder->decimalDigits = 'Default 2, max 5, min 1';

/* Alert */
$lang->workflowfield->alert = new stdclass();
$lang->workflowfield->alert->common                       = 'Alert';
$lang->workflowfield->alert->update                       = 'The field may be used in below functions, please check and update manually.';
$lang->workflowfield->alert->delete                       = 'The field may be used in below functions, please check and delete manually.';
$lang->workflowfield->alert->separater                    = ', ';
$lang->workflowfield->alert->types['fieldExpression']     = "The expression of the <strong>%s</strong> fields of the <strong>%s</strong> flow.";
$lang->workflowfield->alert->types['conditionSql']        = "The <strong>SQL of conditions</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['verificationSql']     = "The <strong>SQL of verifications</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['verificationSqlVar']  = "The SQL variables <strong>%s</strong> of the verifications of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionSql']    = "The <strong>SQL of hook's conditions</strong> of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionSqlVar'] = "The SQL variables <strong>%s</strong> of the hooks' conditions of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookConditionField']  = "The <strong>%s</strong> fields of the hooks' conditions of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookField']           = "The <strong>%s</strong> fields of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookFieldFormula']    = "The expression of the <strong>%s</strong> fields of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";
$lang->workflowfield->alert->types['hookWhere']           = "The <strong>%s</strong> conditions of the hooks of the <strong>%s</strong> flow's <strong>%s</strong> action.";

/* Error */
$lang->workflowfield->error = new stdclass();
$lang->workflowfield->error->remainFields     = '<strong> %s </strong> is a reserved keyword in the system, please change the field code.';
$lang->workflowfield->error->emptyOptions     = 'Empty <strong>key</strong> and <strong>value</strong>.';
$lang->workflowfield->error->wrongCode        = 'The <strong> %s </strong> should be letters.';
$lang->workflowfield->error->longCode         = 'The length of the <strong> %s </strong> should not exceed 30.';
$lang->workflowfield->error->wrongSQL         = 'The SQL is wrong! Error: ';
$lang->workflowfield->error->notunique        = 'unique check';
$lang->workflowfield->error->defaultValue     = 'The length of the <strong> default value </strong> should not exceed %s.';
$lang->workflowfield->error->textDefaultValue = 'The text-field has no default value.';
$lang->workflowfield->error->duplicatedCode   = 'Please reset the duplicated <strong>Keys</strong> %s .';
$lang->workflowfield->error->emptyDefault     = 'Select a item as <strong>default</strong>.';
$lang->workflowfield->error->emptyCustomField = 'You have not added a field. Add one first.';
$lang->workflowfield->error->length           = '<strong>%s</strong> should be greater than or equal to <strong>%s</strong>, and less than or equal to <strong>%s</strong>.';
$lang->workflowfield->error->digits           = '<strong>%s</strong> should be greater than or equal to <strong>%s</strong>.';
$lang->workflowfield->error->dateFormat       = '<strong> Date </strong> format is wrong, must be Y-m-d.';
$lang->workflowfield->error->timeFormat       = '<strong> Datetime </strong> format is wrong, must be Y-m-d H:i:s.';
$lang->workflowfield->error->intSize          = 'The length of the <strong> default value </strong> should be greater than or equal to %s,and less than or equal to %s .';
$lang->workflowfield->error->float            = 'The <strong> default value </strong> should be a number, which can be a decimal.';

/* Formula */
$lang->workflowfield->formula = new stdclass();
$lang->workflowfield->formula->common    = 'Expression';
$lang->workflowfield->formula->target    = 'Target';
$lang->workflowfield->formula->operator  = 'Operator';
$lang->workflowfield->formula->numbers   = 'Number';
$lang->workflowfield->formula->clearLast = 'Delete';
$lang->workflowfield->formula->clearAll  = 'Delete All';
$lang->workflowfield->formula->set       = 'Setting';

$lang->workflowfield->formula->functions['sum']     = 'Total_%s_%s';
$lang->workflowfield->formula->functions['average'] = 'Average_%s_%s';
$lang->workflowfield->formula->functions['max']     = 'Max_%s_%s';
$lang->workflowfield->formula->functions['min']     = 'Min_%s_%s';
$lang->workflowfield->formula->functions['count']   = 'Quantity_%s_%s';

$lang->workflowfield->formula->error = new stdclass();
$lang->workflowfield->formula->error->empty = 'Expression can not be empty.';
$lang->workflowfield->formula->error->error = 'Expression is not correct.';

$lang->workflowfield->excel = new stdclass();
$lang->workflowfield->excel->tips = "1. Name and Field is required. 2. The Options should be in 'key,value' format, separated by comma, multiple groups separated by a newline.";
